collide_chain_segment_and_capsule

Function collide_chain_segment_and_capsule 

pub fn collide_chain_segment_and_capsule(
    segment_a: ChainSegment,
    transform_a: Transform,
    capsule_b: Capsule,
    transform_b: Transform,
    cache: Option<&mut SimplexCache>,
) -> Manifold
Compute the contact manifold between a chain segment and a capsule.

Provide cache when repeatedly colliding against nearby rounded shapes to warm-start the internal edge solver.