pub fn try_shape_distance(
input: DistanceInput,
cache: &mut SimplexCache,
) -> ApiResult<DistanceOutput>Expand description
Compute the closest distance between two shape proxies with recoverable validation.
pub fn try_shape_distance(
input: DistanceInput,
cache: &mut SimplexCache,
) -> ApiResult<DistanceOutput>Compute the closest distance between two shape proxies with recoverable validation.