pub fn solve_planes<V: Into<Vec2>>(
target_delta: V,
planes: &mut [CollisionPlane],
) -> Result<PlaneSolverResult>Expand description
Solve the translation that best satisfies the supplied mover collision planes.
The push field on each collision plane is updated in place by Box2D.
Invalid values, callback re-entry, and unavailable native foundation state are reported.