pub struct ReplayConfig { /* private fields */ }Expand description
Configuration consumed by ReplayPlayer creation.
Implementations
Sourceimpl ReplayConfig
impl ReplayConfig
Sourcepub fn with_worker_count(self, worker_count: WorkerCount) -> Self
pub fn with_worker_count(self, worker_count: WorkerCount) -> Self
Select the validated replay worker count.
Sourcepub fn with_friction_mixer<F>(self, identity: MixerId, mixer: F) -> Self
pub fn with_friction_mixer<F>(self, identity: MixerId, mixer: F) -> Self
Install the deterministic friction mixer required by the recording sidecar.
Sourcepub fn with_restitution_mixer<F>(self, identity: MixerId, mixer: F) -> Self
pub fn with_restitution_mixer<F>(self, identity: MixerId, mixer: F) -> Self
Install the deterministic restitution mixer required by the recording sidecar.
Sourcepub fn mixer_identities(&self) -> MixerIdentities
pub fn mixer_identities(&self) -> MixerIdentities
Return the exact material-mixer behavior identities represented by this configuration.