SnapshotRestore

Struct SnapshotRestore 

pub struct SnapshotRestore { /* private fields */ }
Safe-ID mappings published by a successful in-place restore.

Implementations

Source

impl SnapshotRestore

pub fn body_mappings( &self, ) -> impl ExactSizeIterator<Item = (BodyId, BodyId)> + '_

Iterates over every body ID mapping from the captured snapshot to the restored world.

pub fn shape_mappings( &self, ) -> impl ExactSizeIterator<Item = (ShapeId, ShapeId)> + '_

Iterates over every shape ID mapping from the captured snapshot to the restored world.

pub fn joint_mappings( &self, ) -> impl ExactSizeIterator<Item = (JointId, JointId)> + '_

Iterates over every joint ID mapping from the captured snapshot to the restored world.

pub fn chain_mappings( &self, ) -> impl ExactSizeIterator<Item = (ChainId, ChainId)> + '_

Iterates over every chain ID mapping from the captured snapshot to the restored world.

pub fn body_id(&self, snapshot_id: BodyId) -> Option<BodyId>

pub fn shape_id(&self, snapshot_id: ShapeId) -> Option<ShapeId>

pub fn joint_id(&self, snapshot_id: JointId) -> Option<JointId>

pub fn chain_id(&self, snapshot_id: ChainId) -> Option<ChainId>