pub struct ContactData {
pub contact_id: ContactId,
pub shape_id_a: ShapeId,
pub shape_id_b: ShapeId,
pub manifold: Manifold,
}Expand description
Contact data for a single contact touching two shapes in one completed-step epoch.
Its ContactId expires before the next valid world step enters Box2D.
Fields
contact_id: ContactIdshape_id_a: ShapeIdshape_id_b: ShapeIdmanifold: ManifoldTrait Implementations
Sourceimpl Clone for ContactData
impl Clone for ContactData
Sourcefn clone(&self) -> ContactData
fn clone(&self) -> ContactData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ContactData