pub struct WorldCastOutput {
pub normal: Vec2,
pub point: Position,
pub fraction: f32,
pub iterations: i32,
pub hit: bool,
}Expand description
Result of a cast whose hit point is an absolute world position.
Fields
normal: Vec2Unit surface normal in world orientation.
point: PositionAbsolute world-space hit position.
fraction: f32Fraction of the cast translation at which the hit occurred.
iterations: i32hit: boolImplementations