solve_planes

Function solve_planes 

pub fn solve_planes<V: Into<Vec2>>(
    target_delta: V,
    planes: &mut [CollisionPlane],
) -> PlaneSolverResult
Solve the translation that best satisfies the supplied mover collision planes.

The push field on each collision plane is updated in place by Box2D.